@@ -38,6 +38,9 @@ FAILEDOPERATION_IMAGEDOWNLOADERROR = 'FailedOperation.ImageDownloadError'
 # 超出Entity数量限制。
 FAILEDOPERATION_IMAGEENTITYCOUNTEXCEED = 'FailedOperation.ImageEntityCountExceed'
 
+# 停止服务，控制台开关关闭。
+FAILEDOPERATION_IMAGEGROUPCHARGESTATUSCLOSE = 'FailedOperation.ImageGroupChargeStatusClose'
+
 # 图库为空。
 FAILEDOPERATION_IMAGEGROUPEMPTY = 'FailedOperation.ImageGroupEmpty'
 
@@ -185,6 +188,9 @@ LIMITEXCEEDED_TOOLARGEFILEERROR = 'LimitExceeded.TooLargeFileError'
 # 必选参数为空。
 MISSINGPARAMETER_ERRORPARAMETEREMPTY = 'MissingParameter.ErrorParameterEmpty'
 
+# 请求的次数超过了频率限制。
+REQUESTLIMITEXCEEDED = 'RequestLimitExceeded'
+
 # 账号已欠费。
 RESOURCEUNAVAILABLE_INARREARS = 'ResourceUnavailable.InArrears'
 
